@@ -23,9 +23,10 @@ CovMrcd <- function(x,
     n <- dx[1]; p <- dx[2]
     dimn <- dimnames(x)
 
+    ## VT::18.07.2022 - maxcond passed to the lowlevel function
     mcd <- .detmrcd (x, alpha=alpha, h=h, hsets.init = initHsets,
 		      save.hsets=save.hsets, # full.h=full.h,
-		      rho=rho, target=if(target=="identity") 0 else 1,
+		      rho=rho, maxcond=maxcond, target=if(target=="identity") 0 else 1,
               maxcsteps=maxcsteps,
               trace=as.integer(trace))
 
@@ -37,11 +38,6 @@ CovMrcd <- function(x,
     ans$cov <- mcd$initcovariance
     ans$center <- as.vector(mcd$initmean)
 
-    if(!is.null(nms <- dimn[[2]])) {
-        dimnames(ans$cov) <- list(nms, nms)
-        names(ans$center) <- nms
-    }
-
     ans$n.obs <- n
     ans$best <- sort(as.vector(mcd$best))
     ans$alpha <- alpha
@@ -61,6 +57,12 @@ CovMrcd <- function(x,
     ans <- c(ans, mcd[c("calpha", "iBest","n.csteps", if(save.hsets) "initHsets", "icov","rho", "target")])
     class(ans) <- "mcd"
 
+    if(!is.null(nms <- dimn[[2]])) {
+        dimnames(ans$cov) <- list(nms, nms)
+        dimnames(ans$icov) <- list(nms, nms)
+        names(ans$center) <- nms
+    }
+
     new("CovMrcd",
         call= ans$call,
         crit=ans$crit,
